[FFmpeg-soc] [soc]: r4162 - amr/amrnbfloatdec.c

kmalaussene subversion at mplayerhq.hu
Wed Mar 4 21:13:10 CET 2009


Author: kmalaussene
Date: Wed Mar  4 21:13:10 2009
New Revision: 4162

Log:
Cosmetics: replace unmappable char γ by gamma.

Modified:
   amr/amrnbfloatdec.c

Modified: amr/amrnbfloatdec.c
==============================================================================
--- amr/amrnbfloatdec.c	Wed Mar  4 20:52:49 2009	(r4161)
+++ amr/amrnbfloatdec.c	Wed Mar  4 21:13:10 2009	(r4162)
@@ -66,7 +66,7 @@ typedef struct AMRContext {
     float   pitch_vector[AMR_SUBFRAME_SIZE]; ///< adaptive code book (pitch) vector
     float   fixed_vector[AMR_SUBFRAME_SIZE]; ///< algebraic code book (fixed) vector
 
-    float               prediction_error[4]; ///< quantified prediction errors {20log10(^γ_gc)} for previous four subframes
+    float               prediction_error[4]; ///< quantified prediction errors {20log10(^gamma_gc)} for previous four subframes
     float                     pitch_gain[5]; ///< quantified pitch gains for the current and previous four subframes
     float                     fixed_gain[5]; ///< quantified fixed gains for the current and previous four subframes
 
@@ -695,7 +695,7 @@ static float fixed_gain_prediction(float
 
 static void decode_gains(AMRContext *p, const AMRNBSubframe *amr_subframe, const enum Mode mode, const int subframe)
 {
-    float fixed_gain_factor; // fixed gain correction factor {^γ_gc} for the current frame
+    float fixed_gain_factor; // fixed gain correction factor {^gamma_gc} for the current frame
 
     // decode pitch gain and fixed gain correction factor
     if(mode == MODE_122 || mode == MODE_795) {



More information about the FFmpeg-soc mailing list